@@ -59,6 +59,12 @@
 #define FAN_ALLOW 1
 #define FAN_DENY 2
 #endif
+
+// This code is at the center of many performance issues. The following
+// ensure that it is optimized the most without making all of the audit
+// subsystem bigger.
+#pragma GCC optimize("O3")
+
 #include "auparse-defs.h"
 #include "gen_tables.h"
 #include "common.h"
@@ -322,16 +328,6 @@ static void key_escape(const char *orig, char *dest, auparse_esc_t escape_mode)
 	}
 }
 
-static int is_int_string(const char *str)
-{
-	while (*str) {
-		if (!isdigit((unsigned char)*str))
-			return 0;
-		str++;
-	}
-	return 1;
-}
-
 static int is_hex_string(const char *str)
 {
 	while (*str) {
@@ -424,6 +420,9 @@ int load_interpretation_list(const char *buffer)
 		il.cnt = 0;
 
 	il.record = buf = strdup(buffer);
+	if (buf == NULL) {
+		goto err_out;
+	}
 	if (strncmp(buf, "SADDR=", 6) == 0) {
 		// We have SOCKADDR record. It has no other values.
 		// Handle it by itself.
@@ -595,7 +594,7 @@ static const char *aulookup_uid(uid_t uid, char *buf, size_t size)
 	return buf;
 }
 
-void lookup_destroy_uid_list(void)
+void aulookup_destroy_uid_list(void)
 {
 	if (uid_cache_created == 0)
 		return;
@@ -671,6 +670,11 @@ void _auparse_flush_caches(void)
 	}
 }
 
+void aulookup_metrics(unsigned int *uid, unsigned int *gid)
+{
+	*uid = uid_cache->count;
+	*gid = gid_cache->count;
+}
 static const char *print_uid(const char *val, unsigned int base)
 {
         int uid;
@@ -3236,15 +3240,21 @@ int auparse_interp_adjust_type(int rtype, const char *name, const char *val)
 			rtype == AUDIT_DEL_GROUP))
 		type = AUPARSE_TYPE_GID;
 	else if (rtype == AUDIT_TRUSTED_APP) {
-		if (val[0] == '"')
-			type = AUPARSE_TYPE_ESCAPED;
-		else if (is_int_string(val))
-			type = AUPARSE_TYPE_UNCLASSIFIED;
-		/* Check if we have string with only HEX symbols */
-		else if (is_hex_string(val))
-			type = AUPARSE_TYPE_ESCAPED;
-		else
-			type = AUPARSE_TYPE_UNCLASSIFIED;
+		/*
+		 * Could be anything. See if we know the type. If not,
+		 * take a guess based on contents of value.
+		 */
+		type = lookup_type(name);
+		if (type == AUPARSE_TYPE_UNCLASSIFIED) {
+			if (val[0] == '"')
+				type = AUPARSE_TYPE_ESCAPED;
+			else if (strcmp(name, "pid") == 0)
+				type = AUPARSE_TYPE_UNCLASSIFIED;
+			/* Check if we have string with only HEX symbols */
+			else if (is_hex_string(val))
+				type = AUPARSE_TYPE_ESCAPED;
+			/* Otherwise it really is AUPARSE_TYPE_UNCLASSIFIED */
+		}
 	} else if (rtype == AUDIT_KERN_MODULE && strcmp(name, "name") == 0)
 		type = AUPARSE_TYPE_ESCAPED;
 	else
