@@ -1,6 +1,6 @@
 /*
  * normalize_syscall_map.h
- * Copyright (c) 2016-17,2021-23 Red Hat Inc.
+ * Copyright (c) 2016-17,2021-24 Red Hat Inc.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -29,9 +29,11 @@ _S(NORM_FILE_STAT, "faccessat2")
 _S(NORM_FILE_CHPERM, "chmod")
 _S(NORM_FILE_CHPERM, "fchmod")
 _S(NORM_FILE_CHPERM, "fchmodat")
+_S(NORM_FILE_CHPERM, "fchmodat2")
 _S(NORM_FILE_CHOWN, "chown")
 _S(NORM_FILE_CHOWN, "fchown")
 _S(NORM_FILE_CHOWN, "fchownat")
+_S(NORM_FILE_CHOWN, "fchownat2")
 _S(NORM_FILE_CHOWN, "lchown")
 _S(NORM_FILE_LDMOD, "finit_module")
 _S(NORM_FILE_LDMOD, "init_module")
@@ -39,6 +41,7 @@ _S(NORM_FILE_UNLDMOD, "delete_module")
 _S(NORM_FILE_CHATTR, "setxattr")
 _S(NORM_FILE_CHATTR, "fsetxattr")
 _S(NORM_FILE_CHATTR, "lsetxattr")
+_S(NORM_FILE_CHATTR, "mount_setattr")
 _S(NORM_FILE_DIR, "mkdir")
 _S(NORM_FILE_DIR, "mkdirat")
 _S(NORM_FILE_MOUNT, "fsconfig")
@@ -55,16 +58,20 @@ _S(NORM_FILE_STAT, "stat64")
 _S(NORM_FILE_STAT, "statx")
 _S(NORM_FILE_SYS_STAT, "statfs")
 _S(NORM_FILE_SYS_STAT, "fstatfs")
+_S(NORM_FILE_SYS_STAT, "statmount")
 _S(NORM_FILE, "creat")
 _S(NORM_FILE, "fallocate")
 _S(NORM_FILE, "truncate")
 _S(NORM_FILE, "ftruncate")
 _S(NORM_FILE, "memfd_create")
+_S(NORM_FILE, "memfd_secret")
 _S(NORM_FILE, "open")
 _S(NORM_FILE, "openat")
 _S(NORM_FILE, "openat2")
 _S(NORM_FILE, "readlink")
 _S(NORM_FILE, "readlinkat")
+_S(NORM_FILE, "open_by_handle_at")
+_S(NORM_FILE, "pidfd_getfd")
 _S(NORM_FILE_CHATTR, "removexattr")
 _S(NORM_FILE_CHATTR, "fremovexattr")
 _S(NORM_FILE_CHATTR, "lremovexattr")
@@ -107,6 +114,7 @@ _S(NORM_GID, "setregid")
 _S(NORM_GID, "setresgid")
 _S(NORM_SYSTEM_TIME, "settimeofday")
 _S(NORM_SYSTEM_TIME, "clock_settime")
+_S(NORM_SYSTEM_TIME, "clock_settime64")
 _S(NORM_SYSTEM_TIME, "stime")
 _S(NORM_SYSTEM_TIME, "adjtimex")
 _S(NORM_MAKE_DEV, "mknod")
@@ -115,7 +123,13 @@ _S(NORM_SYSTEM_NAME, "sethostname")
 _S(NORM_SYSTEM_NAME, "setdomainname")
 _S(NORM_SYSTEM_MEMORY, "mmap")
 _S(NORM_SYSTEM_MEMORY, "brk")
+_S(NORM_SYSTEM_MEMORY, "map_shadow_stack")
 _S(NORM_SCHEDULER, "sched_setparam")
 _S(NORM_SCHEDULER, "sched_setscheduler")
 _S(NORM_SCHEDULER, "sched_setattr")
+_S(NORM_SECURITY_POLICY, "landlock_create_ruleset")
+_S(NORM_SECURITY_POLICY, "landlock_add_rule")
+_S(NORM_SECURITY_POLICY, "landlock_restrict_self")
+_S(NORM_SECURITY_POLICY, "lsm_set_self_attr")
+_S(NORM_SECURITY_POLICY, "mseal")
 
