@@ -6,7 +6,7 @@ srcdir = os.getenv('srcdir')
 buf = ["type=LOGIN msg=audit(1143146623.787:142): login pid=2027 uid=0 old auid=4294967295 new auid=848\ntype=SYSCALL msg=audit(1143146623.875:143): arch=c000003e syscall=188 success=yes exit=0 a0=7fffffa9a9f0 a1=3958d11333 a2=5131f0 a3=20 items=1 pid=2027 auid=848 uid=0 gid=0 euid=0 suid=0 fsuid=0 egid=0 sgid=0 fsgid=0 tty=tty3 comm=\"login\" exe=\"/bin/login\" subj=system_u:system_r:local_login_t:s0-s0:c0.c255\n",
 "type=USER_LOGIN msg=audit(1143146623.879:146): user pid=2027 uid=0 auid=848 msg=\'uid=848: exe=\"/bin/login\" (hostname=?, addr=?, terminal=tty3 res=success)\'\n",
 ]
-files = ["%s%s" % (srcdir,"/test.log"), "%s%s" % (srcdir,"/test2.log")]
+files = ["%s%s" % (srcdir,"/test2.log"), "%s%s" % (srcdir,"/test.log")]
 
 import sys
 import time
@@ -15,7 +15,6 @@ if False:
     sys.path.insert(0, load_path)
 
 import auparse
-import audit
 
 def none_to_null(s):
     'used so output matches C version'
@@ -43,7 +42,7 @@ def walk_test(au):
         while True:
             print("    record %d of type %d(%s) has %d fields" % \
                   (record_cnt,
-                   au.get_type(), audit.audit_msg_type_to_name(au.get_type()),
+                   au.get_type(), au.get_type_name(),
                    au.get_num_fields()))
             print("    line=%d file=%s" % (au.get_line_number(), au.get_filename()))
             event = au.get_timestamp()
@@ -76,7 +75,7 @@ def light_test(au):
         while True:
             print("    record %d of type %d(%s) has %d fields" % \
                   (record_cnt,
-                   au.get_type(), audit.audit_msg_type_to_name(au.get_type()),
+                   au.get_type(), au.get_type_name(),
                    au.get_num_fields()))
             print("    line=%d file=%s" % (au.get_line_number(), au.get_filename()))
             event = au.get_timestamp()
@@ -136,7 +135,7 @@ def feed_callback(au, cb_event_type, event_cnt):
         while True:
             print("    record %d of type %d(%s) has %d fields" % \
                   (record_cnt,
-                   au.get_type(), audit.audit_msg_type_to_name(au.get_type()),
+                   au.get_type(), au.get_type_name(),
                    au.get_num_fields()))
             print("    line=%d file=%s" % (au.get_line_number(), au.get_filename()))
             event = au.get_timestamp()
