@@ -1,7 +1,7 @@
 /*
 * ausearch-llist.c - Minimal linked list library
-* Copyright (c) 2005 Red Hat Inc., Durham, North Carolina.
-* All Rights Reserved. 
+* Copyright (c) 2005 Red Hat Inc.
+* All Rights Reserved.
 *
 * This software may be freely redistributed and/or modified under the
 * terms of the GNU General Public License as published by the Free
@@ -15,7 +15,7 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING. If not, write to the
-* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor 
+* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor
 * Boston, MA 02110-1335, USA.
 *
 * Authors:
@@ -59,15 +59,17 @@ lnode *list_next(llist *l)
 	return l->cur;
 }
 
-void list_append(llist *l, const struct audit_rule_data *r, size_t sz)
+int list_append(llist *l, const struct audit_rule_data *r, size_t sz)
 {
 	lnode* newnode;
 
 	newnode = malloc(sizeof(lnode));
+	if (newnode == NULL)
+		return 1;
 
 	if (r) {
 		void *rr = malloc(sz);
-		if (rr) 
+		if (rr)
 			memcpy(rr, r, sz);
 		newnode->r = rr;
 	} else
@@ -85,6 +87,8 @@ void list_append(llist *l, const struct audit_rule_data *r, size_t sz)
 	// make newnode current
 	l->cur = newnode;
 	l->cnt++;
+
+	return 0;
 }
 
 void list_clear(llist* l)
