@@ -77,11 +77,6 @@ int start_config_manager(struct auditd_event *e)
 	return rc;
 }
 
-void shutdown_config(void)
-{
-        pthread_cancel(config_thread);
-}
-
 static void *config_thread_main(void *arg)
 {
 	sigset_t sigs;
