@@ -47,6 +47,11 @@ void lol_create(lol *lo)
 	lo->maxi = -1;
 	lo->limit = ARRAY_LIMIT;
 	lo->array = (lolnode *)malloc(size);
+	if (lo->array == NULL) {
+		fprintf(stderr, "Out of memory. Check %s file, %d line", __FILE__, __LINE__);
+		lo->limit = 0;
+		return;
+	}
 	memset(lo->array, 0, size);
 }
 
@@ -158,13 +163,14 @@ static int compare_event_time(event *e1, event *e2)
 }
 
 #ifndef HAVE_STRNDUPA
-static inline char *strndupa(const char *old, size_t n)
-{
-	size_t len = strnlen(old, n);
-	char *tmp = alloca(len + 1);
-	tmp[len] = 0;
-	return memcpy(tmp, old, len);
-}
+#define strndupa(s, n)								\
+	({												\
+		const char *__old = (s);					\
+		size_t __len = strnlen (__old, (n));		\
+		char *__new = (char *) alloca(__len + 1);	\
+		__new[__len] = '\0';						\
+		(char *) memcpy (__new, __old, __len);		\
+	})
 #endif
 
 /*
@@ -239,7 +245,7 @@ static int extract_timestamp(const char *b, event *e)
 	return 0;
 }
 
-// This function will check events to see if they are complete 
+// This function will check events to see if they are complete
 // FIXME: Can we think of other ways to determine if the event is done?
 static void check_events(lol *lo, time_t sec)
 {
@@ -305,6 +311,11 @@ int lol_add_record(lol *lo, char *buff)
 	n.a1 = 0L;
 	n.type = e.type;
 	n.message = strdup(buff);
+	if(n.message == NULL) {
+		free((char *)e.node);
+		fprintf(stderr, "Out of memory. Check %s file, %d line", __FILE__, __LINE__);
+		return 0;
+	}
 	ptr = strchr(n.message, AUDIT_INTERP_SEPARATOR);
 	if (ptr) {
 		n.mlen = ptr - n.message;
@@ -359,6 +370,13 @@ int lol_add_record(lol *lo, char *buff)
 
 	// Create new event and fill it in
 	l = malloc(sizeof(llist));
+	if (l == NULL) {
+		free((char *)e.node);
+		free(n.message);
+		fprintf(stderr, "Out of memory. Check %s file, %d line",
+			__FILE__, __LINE__);
+		return 0;
+	}
 	list_create(l);
 	l->e.milli = e.milli;
 	l->e.sec = e.sec;
