@@ -302,6 +302,10 @@ char *unescape(const char *buf)
 		return NULL;
 
 	str = strndup(buf, ptr - buf);
+	if (str == NULL) {
+		fprintf(stderr, "Out of memory. Check %s file, %d line", __FILE__, __LINE__);
+		return NULL;
+	}
 
 	if (*buf == '(')
 		return str;
