@@ -44,11 +44,13 @@ snode *slist_next(slist *l)
 	return l->cur;
 }
 
-void slist_append(slist *l, const snode *node)
+int slist_append(slist *l, const snode *node)
 {
 	snode* newnode;
 
 	newnode = malloc(sizeof(snode));
+	if (newnode == NULL)
+		return 1;
 
 	if (node->str)
 		newnode->str = node->str;
@@ -75,6 +77,8 @@ void slist_append(slist *l, const snode *node)
 	// make newnode current
 	l->cur = newnode;
 	l->cnt++;
+
+	return 0;
 }
 
 void slist_clear(slist* l)
